Test Bidi support for Menu Item

ערך חדש for context Menu
Disabled Item
Cut RTL...
Copy LTR...
חדש AUTO...

random link | File... Open LTR ... START AUTO חדש!... חדש AUTO END... חדש... Normal w/o textDir.... Submenu test RTL חדש... חדש new RTL menu... חדש new LTR menu... חדש new Auto menu... Empty auto חדש... חדש Disabled RTL !!! You should not see this
### Navigation menu: Drama RTL ... Comedy LTR ... חדש new disabled submenu START AUTO חדש!... Submenu 2! Different popup חדש checked RTL ... Not Checked Checked Disabled | # Test Bidi support for Menu Item This page contains: "Navigation bar" Menu widget on left, a.k.a vertical MenuBar MenuBar on top page level context menu (right-click anywhere on page) form widget context menu (right-click on textbox widget) Example of programatically created menu Note: while some accelerator (shortcut) keys are displayed in the context menu, they are not actually hooked up to the corresponding actions (if any), they need to be setup explicitly by the user